@@ -1,12 +1,12 @@
 package TAP::Parser::Iterator::PherkinStream;
-$TAP::Parser::Iterator::PherkinStream::VERSION = '0.77';
+$TAP::Parser::Iterator::PherkinStream::VERSION = '0.78';
 =head1 NAME
 
 TAP::Parser::Iterator::PherkinStream - Stream with TAP from async BDD process
 
 =head1 VERSION
 
-version 0.77
+version 0.78
 
 =cut
 
@@ -55,6 +55,8 @@ sub _next {
 
         while (my @ready = $self->{sel}->can_read) {
             for my $fh (@ready) {
+                my $stderr = '';
+
               READ:
                 {
                     my $got = sysread $fh, my ($chunk), 2048;
@@ -62,15 +64,31 @@ sub _next {
                         $self->{sel}->remove($fh);
                     }
                     elsif ($fh == $self->{err_fh}) {
-                        print STDERR $chunk;
+                        $stderr .= $chunk;
+                        my @lines = split(/\n/, $stderr, -1);
+                        $stderr = pop @lines;
+
+                        for my $line (@lines) {
+                            utf8::decode($line);
+                            print STDERR $line . "\n";
+                        }
                         goto READ if $got == 2048;
+
+                        utf8::decode($stderr)
+                            or die 'Subprocess provided non-utf8 data';
+                        print STDERR $stderr . "\n";
                     }
                     else {
                         $part .= $chunk;
                         push @buf, split(/\n/, $part, -1);
                         $part = pop @buf;
 
-                        return shift @buf if @buf;
+                        my $rv = shift @buf;
+                        if (defined $rv) {
+                            utf8::decode($rv)
+                                or die 'Subprocess provided non-utf8 data';
+                            return $rv;
+                        }
                     }
                 }
             }
