@@ -1,12 +1,12 @@
 package TAP::Parser::SourceHandler::Feature;
-$TAP::Parser::SourceHandler::Feature::VERSION = '0.77';
+$TAP::Parser::SourceHandler::Feature::VERSION = '0.78';
 =head1 NAME
 
 TAP::Parser::SourceHandler::Feature - Test::BDD::Cucumber's prove integration
 
 =head1 VERSION
 
-version 0.77
+version 0.78
 
 =cut
 
@@ -88,9 +88,11 @@ sub make_iterator {
 
     my ( $input_out_fh, $output_out_fh );
     pipe $input_out_fh, $output_out_fh;
+    binmode $output_out_fh, ':utf8';
 
     my ( $input_err_fh, $output_err_fh );
     pipe $input_err_fh, $output_err_fh;
+    binmode $output_err_fh, ':utf8';
 
     # Don't cache the output so prove sees it immediately
     #  (pipes are stdio buffered by default)
