@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.77';
+$Test::BDD::Cucumber::Executor::VERSION = '0.78';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.77
+version 0.78
 
 =head1 DESCRIPTION
 
@@ -701,7 +701,7 @@ sub _extract_match_strings {
 sub _test_output {
     my ($self, $events) = @_;
     my $fmt = Test2::Formatter::TAP->new();
-    open my $stdout, '>', \my $out_text;
+    open my $stdout, '>:encoding(UTF-8)', \my $out_text;
     my $idx = 0;
 
     $fmt->set_handles([ $stdout, $stdout ]);
